# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['altb', 'altb.common', 'altb.model']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0',
 'blessed>=1.19.0,<2.0.0',
 'getch>=1.0,<2.0',
 'natsort>=8.3.1,<9.0.0',
 'pydantic>=1.8.2,<2.0.0',
 'rich>=13.3.3,<14.0.0',
 'typer>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['altb = altb.main:main']}

setup_kwargs = {
    'name': 'altb',
    'version': '0.5.2',
    'description': 'Cli tool for tracking over binaries and easily swapping between them',
    'long_description': '# altb\naltb is a cli utility influenced by `update-alternatives` of ubuntu.  \nLinked paths are added to `$HOME/.local/bin` according to [XDG Base Directory Specification](https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html).  \nConfig file is located at `$HOME/.config/altb/config.yaml`.\n\n### How to start?\n\n**Must use Python > 3.9**\nexecute:\n```bash\npipx install altb\n```\n\nto track new binary use:\n```bash\naltb track path <app_name>@<app_tag> /path/to/binary\n```\nfor example:\n```bash\naltb track path python@2.7 /bin/python2.7\naltb track path python@3.8 /bin/python3.8\n# altb track path python ~/Downloads/python # will also work and generate a new hash for it\n```\n\nList all tracked versions:\n```bash\n$ altb list -a\npython\n|----   2.7 - /bin/python2.7\n|----   3.8 - /bin/python3.8\n```\n\nUse specific version:\n```bash\naltb use <app_name>[@<app_tag>]\n```\n\nexample:\n```bash\naltb use python@2.7\n```\nthis will link the tracked path to `~/.local/bin/<app_name>` in this case - `~/.local/bin/python`\n\nCopy specific standalone binary automatically to `~/.local/share/altb/versions/<app_name>/<app_name>_<tag>`\n```bash\naltb track path helm@3 ~/Downloads/helm --copy\n```\n\nYou can run custom commands using:\n```bash\naltb track command special_command@latest "echo This is a command"\n```\nthis especially useful for latest developments, example:\n```bash\naltb track command special_command@latest "go run ./cmd/special_command" --working-directory "$HOME/special_command"\n```\n\n\n## Docs\n### Migrations\n- [Migrate to v0.5.0 and above from lower versions](./docs/migrations/migrate_to_0_5_0.md)',
    'author': 'Elran Shefer',
    'author_email': 'elran777@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/IamShobe/altb',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
